==> quarkus-vertx-http-1.0.0.Final-sources.jar: io/quarkus/vertx/http/runtime/FormAuthConfig$$accessor.java <==
package io.quarkus.vertx.http.runtime;
public final class FormAuthConfig$$accessor {
    private FormAuthConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enabled(Object __instance) {
        return ((FormAuthConfig)__instance).enabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_enabled(Object __instance, boolean enabled) {
        ((FormAuthConfig)__instance).enabled = enabled;
    }
    @SuppressWarnings("unchecked")
    public static Object get_loginPage(Object __instance) {
        return ((FormAuthConfig)__instance).loginPage;
    }
    @SuppressWarnings("unchecked")
    public static void set_loginPage(Object __instance, Object loginPage) {
        ((FormAuthConfig)__instance).loginPage = (String)loginPage;
    }
    @SuppressWarnings("unchecked")
    public static Object get_errorPage(Object __instance) {
        return ((FormAuthConfig)__instance).errorPage;
    }
    @SuppressWarnings("unchecked")
    public static void set_errorPage(Object __instance, Object errorPage) {
        ((FormAuthConfig)__instance).errorPage = (String)errorPage;
    }
    @SuppressWarnings("unchecked")
    public static Object get_landingPage(Object __instance) {
        return ((FormAuthConfig)__instance).landingPage;
    }
    @SuppressWarnings("unchecked")
    public static void set_landingPage(Object __instance, Object landingPage) {
        ((FormAuthConfig)__instance).landingPage = (String)landingPage;
    }
    @SuppressWarnings("unchecked")
    public static Object get_timeout(Object __instance) {
        return ((FormAuthConfig)__instance).timeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_timeout(Object __instance, Object timeout) {
        ((FormAuthConfig)__instance).timeout = (java.time.Duration)timeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_newCookieInterval(Object __instance) {
        return ((FormAuthConfig)__instance).newCookieInterval;
    }
    @SuppressWarnings("unchecked")
    public static void set_newCookieInterval(Object __instance, Object newCookieInterval) {
        ((FormAuthConfig)__instance).newCookieInterval = (java.time.Duration)newCookieInterval;
    }
    @SuppressWarnings("unchecked")
    public static Object get_cookieName(Object __instance) {
        return ((FormAuthConfig)__instance).cookieName;
    }
    @SuppressWarnings("unchecked")
    public static void set_cookieName(Object __instance, Object cookieName) {
        ((FormAuthConfig)__instance).cookieName = (String)cookieName;
    }
    public static Object construct() {
        return new FormAuthConfig();
    }
}

==> quarkus-vertx-http-1.3.1.Final-sources.jar: io/quarkus/vertx/http/runtime/FormAuthConfig$$accessor.java <==
package io.quarkus.vertx.http.runtime;
public final class FormAuthConfig$$accessor {
    private FormAuthConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enabled(Object __instance) {
        return ((FormAuthConfig)__instance).enabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_enabled(Object __instance, boolean enabled) {
        ((FormAuthConfig)__instance).enabled = enabled;
    }
    @SuppressWarnings("unchecked")
    public static Object get_loginPage(Object __instance) {
        return ((FormAuthConfig)__instance).loginPage;
    }
    @SuppressWarnings("unchecked")
    public static void set_loginPage(Object __instance, Object loginPage) {
        ((FormAuthConfig)__instance).loginPage = (String)loginPage;
    }
    @SuppressWarnings("unchecked")
    public static Object get_errorPage(Object __instance) {
        return ((FormAuthConfig)__instance).errorPage;
    }
    @SuppressWarnings("unchecked")
    public static void set_errorPage(Object __instance, Object errorPage) {
        ((FormAuthConfig)__instance).errorPage = (String)errorPage;
    }
    @SuppressWarnings("unchecked")
    public static Object get_landingPage(Object __instance) {
        return ((FormAuthConfig)__instance).landingPage;
    }
    @SuppressWarnings("unchecked")
    public static void set_landingPage(Object __instance, Object landingPage) {
        ((FormAuthConfig)__instance).landingPage = (String)landingPage;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_redirectAfterLogin(Object __instance) {
        return ((FormAuthConfig)__instance).redirectAfterLogin;
    }
    @SuppressWarnings("unchecked")
    public static void set_redirectAfterLogin(Object __instance, boolean redirectAfterLogin) {
        ((FormAuthConfig)__instance).redirectAfterLogin = redirectAfterLogin;
    }
    @SuppressWarnings("unchecked")
    public static Object get_timeout(Object __instance) {
        return ((FormAuthConfig)__instance).timeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_timeout(Object __instance, Object timeout) {
        ((FormAuthConfig)__instance).timeout = (java.time.Duration)timeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_newCookieInterval(Object __instance) {
        return ((FormAuthConfig)__instance).newCookieInterval;
    }
    @SuppressWarnings("unchecked")
    public static void set_newCookieInterval(Object __instance, Object newCookieInterval) {
        ((FormAuthConfig)__instance).newCookieInterval = (java.time.Duration)newCookieInterval;
    }
    @SuppressWarnings("unchecked")
    public static Object get_cookieName(Object __instance) {
        return ((FormAuthConfig)__instance).cookieName;
    }
    @SuppressWarnings("unchecked")
    public static void set_cookieName(Object __instance, Object cookieName) {
        ((FormAuthConfig)__instance).cookieName = (String)cookieName;
    }
    public static Object construct() {
        return new FormAuthConfig();
    }
}
